==> orthanc_1.5.4+dfsg.orig.tar.xz: Orthanc-1.5.4/Core/JobsEngine/JobStepResult.h <==
/**
 * Orthanc - A Lightweight, RESTful DICOM Store
 * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
 * Department, University Hospital of Liege, Belgium
 * Copyright (C) 2017-2019 Osimis S.A., Belgium
 *
 * This program is free software: you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * In addition, as a special exception, the copyright holders of this
 * program give permission to link the code of its release with the
 * OpenSSL project's "OpenSSL" library (or with modified versions of it
 * that use the same license as the "OpenSSL" library), and distribute
 * the linked executables. You must obey the GNU General Public License
 * in all respects for all of the code used other than "OpenSSL". If you
 * modify file(s) with this exception, you may extend this exception to
 * your version of the file(s), but you are not obligated to do so. If
 * you do not wish to do so, delete this exception statement from your
 * version. If you delete this exception statement from all source files
 * in the program, then also delete it here.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 **/


#pragma once

#include "../Enumerations.h"

namespace Orthanc
{
  class JobStepResult
  {
  private:
    JobStepCode   code_;
    unsigned int  timeout_;
    ErrorCode     error_;
    
    explicit JobStepResult(JobStepCode code) :
      code_(code),
      timeout_(0),
      error_(ErrorCode_Success)
    {
    }

  public:
    explicit JobStepResult() :
      code_(JobStepCode_Failure),
      timeout_(0),
      error_(ErrorCode_InternalError)
    {
    }

    static JobStepResult Success()
    {
      return JobStepResult(JobStepCode_Success);
    }

    static JobStepResult Continue()
    {
      return JobStepResult(JobStepCode_Continue);
    }

    static JobStepResult Retry(unsigned int timeout);

    static JobStepResult Failure(const ErrorCode& error);

    JobStepCode GetCode() const
    {
      return code_;
    }

    unsigned int GetRetryTimeout() const;

    ErrorCode GetFailureCode() const;
  };
}

==> orthanc_1.5.8+dfsg.orig.tar.xz: Orthanc-1.5.8/Core/JobsEngine/JobStepResult.h <==
/**
 * Orthanc - A Lightweight, RESTful DICOM Store
 * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
 * Department, University Hospital of Liege, Belgium
 * Copyright (C) 2017-2019 Osimis S.A., Belgium
 *
 * This program is free software: you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * In addition, as a special exception, the copyright holders of this
 * program give permission to link the code of its release with the
 * OpenSSL project's "OpenSSL" library (or with modified versions of it
 * that use the same license as the "OpenSSL" library), and distribute
 * the linked executables. You must obey the GNU General Public License
 * in all respects for all of the code used other than "OpenSSL". If you
 * modify file(s) with this exception, you may extend this exception to
 * your version of the file(s), but you are not obligated to do so. If
 * you do not wish to do so, delete this exception statement from your
 * version. If you delete this exception statement from all source files
 * in the program, then also delete it here.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 **/


#pragma once

#include "../Enumerations.h"

namespace Orthanc
{
  class OrthancException;
  
  class JobStepResult
  {
  private:
    JobStepCode   code_;
    unsigned int  timeout_;
    ErrorCode     error_;
    std::string   failureDetails_;
    
    explicit JobStepResult(JobStepCode code) :
      code_(code),
      timeout_(0),
      error_(ErrorCode_Success)
    {
    }

  public:
    explicit JobStepResult() :
      code_(JobStepCode_Failure),
      timeout_(0),
      error_(ErrorCode_InternalError)
    {
    }

    static JobStepResult Success()
    {
      return JobStepResult(JobStepCode_Success);
    }

    static JobStepResult Continue()
    {
      return JobStepResult(JobStepCode_Continue);
    }

    static JobStepResult Retry(unsigned int timeout);

    static JobStepResult Failure(const ErrorCode& error,
                                 const char* details);

    static JobStepResult Failure(const OrthancException& exception);

    JobStepCode GetCode() const
    {
      return code_;
    }

    unsigned int GetRetryTimeout() const;

    ErrorCode GetFailureCode() const;

    const std::string& GetFailureDetails() const;
  };
}
